package com.utopiaindustries.hseobservationsapp.fragments;

import android.app.DatePickerDialog;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;

import androidx.annotation.Nullable;
import androidx.fragment.app.Fragment;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.AutoCompleteTextView;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.utopiaindustries.hseobservationsapp.R;
import com.utopiaindustries.hseobservationsapp.activities.ObservationForms.ObservationOneActivity;
import com.utopiaindustries.hseobservationsapp.adapters.FormTypeAdapter;
import com.utopiaindustries.hseobservationsapp.adapters.ShiftAdapter;
import com.utopiaindustries.hseobservationsapp.models.FormType;
import com.utopiaindustries.hseobservationsapp.models.Shift;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Locale;

public class HomeFragment extends Fragment {

    private int year, month, day;
    private Calendar calendar;
    private TextView txtUserName, txtDate;
    private ImageView imgCalendar;
    private Button btnNext;
    private AutoCompleteTextView shiftTextview, formTextview;

    private ShiftAdapter shiftAdapter;
    private ArrayList<Shift> shiftArrayList = new ArrayList<>();

    private FormTypeAdapter formTypeAdapter;
    private ArrayList<FormType> formArrayList = new ArrayList<>();

    @Override
    public void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        // Inflate the layout for this fragment
        View view = inflater.inflate(R.layout.fragment_home , container, false );

        initializeLayout(view);

        txtUserName.setText("Supervisor Name");

        imgCalendar.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                showDatePickerDialog(getActivity());
            }
        });

        shiftTextview.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                // Perform action when shiftTextview item is clicked
                Toast.makeText(getActivity(), "Item clicked: " + shiftArrayList.get(position).getTitle(), Toast.LENGTH_SHORT).show();

            }
        });

        formTextview.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                // Perform action when formTextview item is clicked
                Toast.makeText(getActivity(), "Item clicked: " + formArrayList.get(position).getTitle(), Toast.LENGTH_SHORT).show();

            }
        });

        btnNext.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                Intent intent = new Intent(getActivity(), ObservationOneActivity.class);
                startActivity(intent);
            }
        });


        return view;
    }

    public void initializeLayout(View view) {
        calendar = Calendar.getInstance();
        year = calendar.get(Calendar.YEAR);
        month = calendar.get(Calendar.MONTH);
        day = calendar.get(Calendar.DAY_OF_MONTH);
        txtUserName = view.findViewById(R.id.txt_user_name);
        txtDate = view.findViewById(R.id.txt_date);
        imgCalendar = view.findViewById(R.id.img_calendar);
        btnNext = view.findViewById(R.id.btn_next);

        shiftTextview = view.findViewById(R.id.shift_textview);
        formTextview = view.findViewById(R.id.form_textview);

        shiftArrayList.add(new Shift(1, "General Shift(08:00AM - 05:00PM)"));
        shiftArrayList.add(new Shift(2, "Evening Shift(12:00PM - 09:00PM)"));
        shiftArrayList.add(new Shift(3, "Night Shift(09:00PM - 06:00AM)"));

        shiftAdapter = new ShiftAdapter(getActivity(), shiftArrayList);
        shiftTextview.setAdapter(shiftAdapter);

        formArrayList.add(new FormType(1, "Observation Form"));
        formArrayList.add(new FormType(2, "Permit To Work Form"));
        formArrayList.add(new FormType(3, "HSE Training Form"));
        formArrayList.add(new FormType(4, "Injury Record Form"));
        formArrayList.add(new FormType(5, "Weekly Activities Form"));
        formArrayList.add(new FormType(6, "Progressive Activities Form"));
        formArrayList.add(new FormType(7, "Other HSE Form"));

        formTypeAdapter = new FormTypeAdapter(getActivity(), formArrayList);
        formTextview.setAdapter(formTypeAdapter);
    }

    private void showDatePickerDialog(Context context) {
        DatePickerDialog datePickerDialog = new DatePickerDialog(
                context,
                new DatePickerDialog.OnDateSetListener() {
                    @Override
                    public void onDateSet(DatePicker view, int year, int monthOfYear, int dayOfMonth) {
                        // Month is 0-indexed, so we add 1
                        Calendar selectedCalendar = Calendar.getInstance();
                        selectedCalendar.set(year, monthOfYear, dayOfMonth);
                        SimpleDateFormat dateFormat = new SimpleDateFormat("MM-dd-yyyy", Locale.getDefault());
                        String selectedDate = dateFormat.format(selectedCalendar.getTime());
                        txtDate.setText(selectedDate);
                    }
                },
                year, month, day
        );
        datePickerDialog.show();
    }
}